<?php

class WPEF_PageController {
    public function __construct() {
        add_action('add_meta_boxes_' . WPEF_SLUG, array($this, 'add_meta_box'), 10000);
        add_action('save_post_' . WPEF_SLUG, array($this, 'save'), 10, 3);
        add_action('template_redirect', array($this, 'get'));
    }

    public function save($post_id, $post, $update) {
        if (!current_user_can('manage_options')) {
            return;
        }

        global $pagenow;

        if( $pagenow === 'post-new.php' ){
            return;
        }

        if ( WPEF_SLUG != $post->post_type ) {
            return;
        }

        $page = new WPEF_Page($post_id);

        $page->days = stripslashes($_POST['days']);
        $page->expire_time = stripslashes($_POST['expire_time']);
        $page->url = stripslashes($_POST['url']);
        $page->expired_url = stripslashes($_POST['expired_url']);
    }

    public function add_meta_box() {
        add_meta_box(
            WPEF_SLUG . '_meta_box', 'Configuration', array($this, 'render'), WPEF_SLUG, 'advanced', 'high'
        );
    }

    public function render($post) {
        $settings = WPEF_WPEverFunnel::instance()->settings;
        $page = new WPEF_Page($post->ID);
        require WPEF_VIEW_DIR . '/page.php';
    }

    public function get() {
        if (is_singular(WPEF_SLUG)) {
            $page = new WPEF_Page(get_the_ID());

            $now = new DateTime();
            $now->setTimezone(new DateTimeZone('America/New_York'));

            try {

                foreach (array('ar', 'dt', 'dn') as $required) {
                    if (!array_key_exists($required, $_GET)) {
                        throw new Exception('Missing data');
                    }
                }

                $autoresponder = stripslashes($_GET['ar']);
                $date = stripslashes($_GET['dt']);
                $day = stripslashes($_GET['dn']);

                $date = WPEF_Autoresponder::parse_date($autoresponder, $date);
                if(!is_numeric($day)){
                    throw new Exception('Bad data');
                }

                //get back to the 'first' day of the promotion
                $date->sub(new DateInterval("P{$day}D"));

                //how long should it be valid for?
                $date->add(new DateInterval("P{$page->days}D"));

                //set the final expiry...
                $parts = explode(':', $page->expire_time);
                $date->setTime($parts[0], $parts[1]);

                if($now > $date){
                    throw new Exception('Expired');
                }
                wp_redirect($page->url);

            }catch (Exception $ex){
                wp_redirect($page->expired_url);
            }
            exit;
        }
    }
}